=====================
Recommended Resources
=====================

Packages We Recommend
=====================
* `Pytest <https://docs.pytest.org/en/latest>`_ -- Python Testing Framework
* `Flake8 <http://flake8.pycqa.org/en/latest>`_ -- Style Enforcement
* `Sphinx <http://www.sphinx-doc.org/en/stable>`_ -- Automated HTML Documentation

Converters
==========
* `PyDMConverter <https://github.com/slaclab/pydm-converter-tool>`_ -- EDM to PyDM Converter

External Tutorials and Guides
=============================
* `Git Tutorial <http://swcarpentry.github.io/git-novice>`_ -- Thorough Git beginner guide
* `Numpy Development Guide <https://docs.scipy.org/doc/numpy/dev/gitwash/development_workflow.html>`_ -- A development guide from the folks at NumPy
* `PEP8 <https://www.python.org/dev/peps/pep-0008>`_ -- Python Coding Conventions
* `Git Flight Rules <https://github.com/k88hudson/git-flight-rules>`_ -- Specific instructions for performing advanced tasks in Git
* `NumPy Documentation Guide <https://github.com/numpy/numpy/blob/master/doc/HOWTO_DOCUMENT.rst.txt>`_ -- Guide to making NumPy style documentation
* `Conda <https://conda.io/docs/user-guide/getting-started.html>`_ -- Getting started guide for using Conda

